# Boilerplate

This repository contains the template files and some pre-defined scheme functions to assist the typesetting of mensural music using **LilyPond**. The design philosophy is to exploit lilypond's ability to separating form and content in order to keep as much of the original intact as possible in the part files, while still retaining the option of forming a score in modern notation that can be used in analysis or performance even by someone unfamiliar with mensural notation.

## Dependencies

A **LilyPond** package for most modern operating systems can be found [here](http://www.lilypond.org/download.html).

## Useage

Place the music, incipit and text inside the relevant lilypond files for each part. Then invoke `lilypond score.ly` to generate the pdf and midi files. If you are trying to typeset music from one of my other repositories, then make sure you have both this repository and the repositories for the music in the same folder. Afterwards `cd` into the folder for the music and invoke `lilypond` on the `score.ly` file there.

### Advanced Useage

This template is designed to generate both the parts in mensural notation and score in modern notation from a single copy of the music written as lilypond code. As such, two sets of definitions are included. `typesetting_functions.ly` includes some functions to reduce boilerplate and simplify typesetting in addition to the formats for modern notation, and should be included at the top of every **LilyPond** document that need to be typeset directly. `testing.ly` includes the additional formats for mensural notation, and should be included in **LilyPond** files and placed after `typesetting_functions.ly`. The tag system in **LilyPond** is made to simplify this process, with music blocks unique to modern typesetting enclosed under the tag `mod`, while the music blocks unique to the original notation and is not desired in modern format are enclosed under the tag `ori`.

### Useful functions

Some common features of white mensural notation, such as minor colouration and variable placement of rests on the staff-line are cubersome to indicate in **LilyPond** in full, however they often contain vital information that cannot be ignored. For example, whether a semibreve rest is placed immediately adjacent or a few lines away from the preceding breve may determine its (im)perfection. Hence some shortcuts are included to keep the music code legible while retaining these critical information.

* `\sbdm` (**s**emi**b**reve **d**otted **m**inim): follow this command with two notes, duration does not matter, and it will produce minor colouration in mensural notation, while giving the correct interpretation as dotted minim + semiminim in modern notation, with the colouration bracket added.

* `\bmm`, `bdsb` (**b**reve **m**inim **m**inim, **b**reve **d**otted **s**emi**b**reve): same effect as above, except for the breve-minim-minim and breve-semibreve patters of minor colouration.

* `\flex`, `\flexe` (**flex**a, **flex**a **e**nd): Encase any ligatured notes in between these commands for oblique noteheads

* `\fic` (musica **fic**ta): Place these in front of any note to get editorial accidentals above the note.

* `\plre` (**pl**ace **re**st): Place this in front of a rest or a group of rests enclosed in curly brackets, followed by a number which indicates its displacement in the staff. `#0` is the centreline, while positive values shift it upwards and negative values shift it downwards.

* `\note-equiv` (**note** **equiv**alence): Used inside a markup block to give editorial suggestion of note equivalence between succeeding sections of different mensuration. This takes two strings of numbers as argument, which conforms to **Lilypond**'s way of recording note duratins. (`#"1."` will print a dotted semibreve, and so on)

* `\timeSigSymb` (**time** **sig**nature **symb**ol): Used to change the mensuration sign or time signature symbol printed. In addition to this some time signature symbols combined with numbers which are not in **Lilypoond**'s list of symbols are provided: `\OThree`, `\OThreeAlt` (O with the number three under it), `\CThree`, `\CutCThree`, `\CTwo`, `\CutCTwo` and `\OTwo`.

## Examples

Here's an example of four-part score in modern notation:
![score-example](https://i.imgur.com/ZDk8cli.png)

And the Discantus part for the same movement:
![part-example](https://i.imgur.com/i67gNO3.png)

The original clef, mensuration sign, ligatures, line-breaks and rest placement are all faithfully reproduced from the source print.

### Editorial Standards

The general editorial procedure follows the suggestions made by Grier in *The Critical Editing of Music*, namely:

* Incipits are provided at the beginning of each independent music section. They provide the original clef, mensuration sign and the first few notes or rests of the primary source.

* All note durations are reduced by one half. This improves legibility for pieces with long notes while avoiding the stemming issues for semiminims in quadruple reduction and above.

* Ligatures are indicated with square bracket above the notes, while colouration (including minor colouration) are indicated with empty brackets.

* Mensural barring, where bar lines are draw between staves instead of inside staves, is used. This helps to provide the readability of regular barring without splitting notes into tied notes.

* Explicit accidentals in the source are placed inside the staff, while editorial accidentals are printed directly above the note. Due to the presence of Mensural barring all accidentals only apply to the note directly under/over them in order to avoid confusion. The editorial accidentals are suggestions only and should be followed with discretion.

* The final long of a piece is, following the reduction procedure, transcribed as a breve. They should be held for indefinite duration.
